######
Marian
######

.. image:: https://travis-ci.org/nebulousdog/marian.svg?branch=master
   :target: https://travis-ci.org/nebulousdog/marian
   :alt: travis-link
.. image:: https://codecov.io/gh/nebulousdog/marian/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/nebulousdog/marian
   :alt: codecov-link

Not really ready for consumption. Making public so I can use handy-dandy Travis-CI.

*******
License
*******

MIT
